@@ -22,5 +22,11 @@ put %v | each {|c|
     }%v
 }
 `
-	return fmt.Sprintf(snippet, pathSnippet("elvish"), strings.Join(completers, " "), windowsSnippet)
+
+	var quotedCompleters []string
+	for _, c := range completers {
+		quotedCompleters = append(quotedCompleters, fmt.Sprintf("%q", c))
+	}
+
+	return fmt.Sprintf(snippet, pathSnippet("elvish"), strings.Join(quotedCompleters, " "), windowsSnippet)
 }
