@@ -72,13 +72,16 @@ var rootCmd = &cobra.Command{
 		case "--diff":
 			diffCmd.SetArgs(args[1:])
 			diffCmd.Execute()
+		case "--edit":
+			editCmd.SetArgs(args[1:])
+			editCmd.Execute()
 		case "--macro":
 			macroCmd.SetArgs(args[1:])
 			macroCmd.Execute()
 		case "-h", "--help":
 			cmd.Help()
 		case "-v", "--version":
-			println("carapace-bin " + cmd.Version)
+			fmt.Println("carapace-bin " + cmd.Version)
 		case "--list":
 			listCmd.SetArgs(args[1:])
 			listCmd.Execute()
@@ -191,6 +194,7 @@ func init() {
 	rootCmd.Flags().Bool("condition", false, "list or execute condition")
 	rootCmd.Flags().Bool("detect", false, "detect bridge by invoking command")
 	rootCmd.Flags().Bool("diff", false, "diff completion")
+	rootCmd.Flags().Bool("edit", false, "edit files")
 	rootCmd.Flags().BoolP("help", "h", false, "help for carapace")
 	rootCmd.Flags().Bool("list", false, "list completers")
 	rootCmd.Flags().Bool("macro", false, "list or execute macros")
@@ -206,6 +210,7 @@ func init() {
 		"condition",
 		"detect",
 		"diff",
+		"edit",
 		"help",
 		"list",
 		"macro",
@@ -243,6 +248,8 @@ func init() {
 				return carapace.ActionExecute(detectCmd).Shift(1)
 			case "--diff":
 				return carapace.ActionExecute(diffCmd).Shift(1)
+			case "--edit":
+				return carapace.ActionExecute(editCmd).Shift(1)
 			case "--help":
 				return carapace.ActionValues()
 			case "--list":
