@@ -2,11 +2,12 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/adb"
 	"github.com/spf13/cobra"
 )
 
 var pullCmd = &cobra.Command{
-	Use:   "pull",
+	Use:   "pull [-a] [-z ALGORITHM] [-Z] REMOTE... LOCAL",
 	Short: "copy files/dirs from device",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
@@ -22,4 +23,15 @@ func init() {
 	carapace.Gen(pullCmd).FlagCompletion(carapace.ActionMap{
 		"z": carapace.ActionValues("any", "none", "brotli"),
 	})
+
+	carapace.Gen(pullCmd).PositionalCompletion(
+		adb.ActionFiles(),
+	)
+
+	carapace.Gen(pullCmd).PositionalAnyCompletion(
+		carapace.Batch(
+			adb.ActionFiles().FilterArgs(),
+			carapace.ActionFiles(),
+		).ToA(),
+	)
 }
