@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/goreleaser"
 	"github.com/spf13/cobra"
 )
 
@@ -16,9 +17,11 @@ func init() {
 	carapace.Gen(initCmd).Standalone()
 
 	initCmd.Flags().StringP("config", "f", "", "Load configuration from file")
+	initCmd.Flags().StringP("language", "l", "", "Which language will be used")
 	rootCmd.AddCommand(initCmd)
 
 	carapace.Gen(initCmd).FlagCompletion(carapace.ActionMap{
-		"config": carapace.ActionFiles(),
+		"config":   carapace.ActionFiles(),
+		"language": goreleaser.ActionLanguages(),
 	})
 }
