@@ -7,20 +7,17 @@ import (
 )
 
 var commitCmd = &cobra.Command{
-	Use:     "commit [OPTIONS] [PATHS]...",
-	Short:   "Update the description and create a new change on top",
-	Aliases: []string{"ci"},
-	Run:     func(cmd *cobra.Command, args []string) {},
+	Use:   "commit",
+	Short: "Update the description and create a new change on top [default alias: ci]",
+	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(commitCmd).Standalone()
 
-	commitCmd.Flags().String("author", "", "Set author to the provided string")
 	commitCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
 	commitCmd.Flags().BoolP("interactive", "i", false, "Interactively choose which changes to include in the first commit")
 	commitCmd.Flags().StringSliceP("message", "m", nil, "The change description to use (don't open editor)")
-	commitCmd.Flags().Bool("reset-author", false, "Reset the author to the configured user")
 	commitCmd.Flags().String("tool", "", "Specify diff editor to be used (implies --interactive)")
 	rootCmd.AddCommand(commitCmd)
 
