@@ -3,6 +3,7 @@ package cmd
 import (
 	"github.com/carapace-sh/carapace"
 	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/git"
+	"github.com/carapace-sh/carapace/pkg/style"
 	"github.com/spf13/cobra"
 )
 
@@ -16,11 +17,17 @@ func init() {
 	carapace.Gen(git_cloneCmd).Standalone()
 
 	git_cloneCmd.Flags().Bool("colocate", false, "Whether or not to colocate the Jujutsu repo with the git repo")
-	git_cloneCmd.Flags().Int("depth", 0, "Create a shallow clone of the given depth")
+	git_cloneCmd.Flags().String("depth", "", "Create a shallow clone of the given depth")
+	git_cloneCmd.Flags().String("fetch-tags", "", "Configure when to fetch tags")
 	git_cloneCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
-	git_cloneCmd.Flags().String("remote", "origin", "Name of the newly created remote")
+	git_cloneCmd.Flags().Bool("no-colocate", false, "Disable colocation of the Jujutsu repo with the git repo")
+	git_cloneCmd.Flags().String("remote", "", "Name of the newly created remote")
 	gitCmd.AddCommand(git_cloneCmd)
 
+	carapace.Gen(git_cloneCmd).FlagCompletion(carapace.ActionMap{
+		"fetch-tags": carapace.ActionValues("all", "included", "none").StyleF(style.ForKeyword),
+	})
+
 	carapace.Gen(git_cloneCmd).PositionalCompletion(
 		git.ActionRepositorySearch(git.SearchOpts{}.Default()),
 		carapace.ActionDirectories(),
