@@ -23,9 +23,11 @@ func init() {
 	operation_showCmd.Flags().Bool("ignore-space-change", false, "Ignore changes in amount of whitespace when comparing lines")
 	operation_showCmd.Flags().Bool("name-only", false, "For each path, show only its path")
 	operation_showCmd.Flags().Bool("no-graph", false, "Don't show the graph, show a flat list of modified changes")
+	operation_showCmd.Flags().Bool("no-op-diff", false, "Do not show operation diff")
 	operation_showCmd.Flags().BoolP("patch", "p", false, "Show patch of modifications to changes")
 	operation_showCmd.Flags().Bool("stat", false, "Show a histogram of the changes")
 	operation_showCmd.Flags().BoolP("summary", "s", false, "For each path, show only whether it was modified, added, or deleted")
+	operation_showCmd.Flags().StringP("template", "T", "", "Render the operation using the given template")
 	operation_showCmd.Flags().String("tool", "", "Generate diff by external command")
 	operation_showCmd.Flags().Bool("types", false, "For each path, show only its type before and after")
 	operationCmd.AddCommand(operation_showCmd)
