@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/completers/common/paru_completer/cmd/common"
 	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/paru"
 	"github.com/spf13/cobra"
 )
@@ -19,6 +20,7 @@ func init() {
 	getpkgbuildCmd.Flags().BoolP("comments", "c", false, "Print AUR comments for pkgbuild")
 	getpkgbuildCmd.Flags().BoolP("print", "p", false, "Print pkgbuild to stdout")
 	getpkgbuildCmd.Flags().BoolP("ssh", "s", false, "Clone package using SSH")
+	common.AddNewFlags(getpkgbuildCmd)
 
 	carapace.Gen(getpkgbuildCmd).PositionalAnyCompletion(
 		paru.ActionPackageSearch().FilterArgs(),
