@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/completers/common/paru_completer/cmd/common"
 	"github.com/spf13/cobra"
 )
 
@@ -18,4 +19,5 @@ func init() {
 	showCmd.Flags().BoolP("complete", "c", false, "Used for completions")
 	showCmd.Flags().BoolP("news", "w", false, "Print arch news")
 	showCmd.Flags().BoolP("stats", "s", false, "Display system package statistics")
+	common.AddNewFlags(showCmd)
 }
