@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/completers/common/paru_completer/cmd/common"
 	"github.com/spf13/cobra"
 )
 
@@ -16,6 +17,7 @@ func init() {
 	carapace.Gen(upgradeCmd).Standalone()
 
 	upgradeCmd.Flags().BoolP("install", "i", false, "Install package as well as building")
+	common.AddNewFlags(upgradeCmd)
 
 	carapace.Gen(upgradeCmd).PositionalAnyCompletion(
 		carapace.ActionFiles(),
